@@ -15,7 +15,7 @@ class Singleton(object):
 
     def __new__(cls, *args, **kwargs):
         if not cls._instance:
-            cls._instance = super(Singleton, cls).__new__(cls, *args, **kwargs)
+            cls._instance = super(Singleton, cls).__new__(cls) # , *args, **kwargs)
         return cls._instance
 
     @property
