@@ -6,21 +6,22 @@ __license__ = "MIT"
 __birthdate__ = '15.11.2021'
 __status__ = 'prod' # options are: dev, test, prod
 
-import pandas as pd
+
+
 from ..core.settings import Settings
-import warnings
 from ..bottomup.stock_manager import StockManager
 from ..core.flow_matrix import FlowMatrix
+
+import pandas as pd
+import warnings
 import numpy as np
 from collections import defaultdict
-from ..misc.mpl_plotting import matplotlib_barplot
-import matplotlib.pyplot as plt
-import matplotlib.patches as mpatches
 from enum import Enum
 from collections import defaultdict
-
 import copy
 
+
+
 class BalanceEntry(Enum):
     """
     these are the different entry types
@@ -317,7 +318,6 @@ class BalanceSheet:
     TODO < insert code here
     """
 
-
     def to_dataframe(self):
         """
         Create a dataframe from this data structure. Warning: this is computationally heavy and should not be used in loops!
@@ -342,7 +342,7 @@ class BalanceSheet:
                                         "Equity": [row[BalanceEntry.EQUITY]],
                                         "Liabilities": [row[BalanceEntry.LIABILITIES]]}) # construct a new row
 
-                #df = df.append(new_row.replace(0.0,null_sym)) # append the new row
+                # df = df.append(new_row.replace(0.0,null_sym)) # append the new row
                 df =  pd.concat([df,new_row.replace(0.0,null_sym)])
 
         df = df.sort_index() # sort the entries by index
@@ -440,6 +440,9 @@ class BalanceSheet:
         """
         creates a matplotlib plot of the balance sheet
         """
+        import matplotlib.pyplot as plt
+        import matplotlib.patches as mpatches
+        from ..misc.mpl_plotting import matplotlib_barplot
 
         balance_sheet = self
 
@@ -553,16 +556,17 @@ class BalanceSheet:
         # print("colors",colors)
 
         fig = matplotlib_barplot(df.T, xlabel="", ylabel="", color=colors, title=title, stacked=True, show_labels=show_labels,fmt="{0:.2f}",
-                                legend="off", size=(5, 5), show=False)
+                                legend="off", size=(4, 4), show=False)
 
-        plt.gca().legend(handles=legend_patches, bbox_to_anchor=(1.25, 1))
+        plt.gca().legend(handles=legend_patches, bbox_to_anchor=(1.3, 1),framealpha=0.0)
+
+        plt.axis("off")
         plt.tight_layout()
-        
         plt.show()
 
 
     @classmethod
-    def plot_list(cls,list_of_balance_sheets,dt=1,xlabel=None,ylabel=None,title=None,show_liabilities=True):
+    def plot_list(cls,list_of_balance_sheets,dt=1,xlabel=None,ylabel=None,title=None,show_liabilities=True,show=True):
         """
         Plots a list of balance sheets (e.g. a collected temporal series)
 
@@ -572,7 +576,11 @@ class BalanceSheet:
         :param ylabel: y axis label
         :param title: title of the figure
         :param show_liabilities: boolean switch to show passive side of balance sheet as downward-pointing bars (default True)
+        :param show: show the plot in a new window? if False, only the matplotlib figure is returned
         """
+        import matplotlib.pyplot as plt
+        import matplotlib.patches as mpatches
+        from ..misc.mpl_plotting import matplotlib_barplot
 
         entries = {}
 
@@ -708,4 +716,7 @@ class BalanceSheet:
         plt.legend(loc=(1.04,0)) # "upper left")
 
         plt.tight_layout()
-        plt.show()
+        if show:
+            plt.show()
+
+        return plt.gcf()
