@@ -61,10 +61,15 @@ class CodeEditor(QtWidgets.QDialog):
 
         self.backup_count = 0
 
+
+        self.setStyleSheet(self.parent().parent().theme_manager.get_stylesheet("main"))
+        self.setStyleSheet(self.parent().parent().theme_manager.get_background_style())
+
+
         self.large_size = QtCore.QSize(1569,874)
-        self.small_size = QtCore.QSize(800,874)
+        self.small_size = QtCore.QSize(950,874)
         self.size = "small"
-        self.pushButton.pressed.connect(self.switch_size)
+        #self.pushButton.pressed.connect(self.switch_size)
 
         self.search_idx = -1
         self.matched_lines = []
@@ -74,6 +79,9 @@ class CodeEditor(QtWidgets.QDialog):
         self.shortcut.activated.connect(self.parent().parent().save_and_build)
         # self.shortcut.activated.connect(lambda: print("ACTIVATED"))
 
+        self.setStyleSheet(self.parent().parent().theme_manager.get_stylesheet("main"))
+        self.setStyleSheet(self.parent().parent().theme_manager.get_background_style())
+
         self.textEdit.installEventFilter(self)
         self.textEdit.cursorPositionChanged.connect(self.update_line_label)
 
@@ -82,7 +90,10 @@ class CodeEditor(QtWidgets.QDialog):
         self.shortcut3 = QShortcut(QKeySequence("Shift+Tab"),self)
         self.shortcut3.activated.connect(self.unindent)
 
-        self.setFixedSize(self.small_size)
+        #self.setFixedSize(self.small_size)
+        #self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+
+        self.setSizeGripEnabled(True)
         self.highlighter = Highlighter(self)
         self.setUpEditor()
 
@@ -99,8 +110,9 @@ class CodeEditor(QtWidgets.QDialog):
         except Exception as e:
             print(str(e))
 
-        self.highlighter_rects = []
-
+        self.highlighter_rects = [] # highlighter for functions
+        self.highlighter_tans = [] # highlighter for transactions
+        self.highlighter_bal = [] # highlighter for balance sheet manipulations
 
         self.count_interpr_max = 5
         self.count_update_max = 5
@@ -155,13 +167,80 @@ class CodeEditor(QtWidgets.QDialog):
             block= self.textEdit.document().findBlockByNumber(block_number)
             brect = self.textEdit.blockBoundingGeometry(block)
             # print("brect", brect)
-            y = int(brect.y()+ offset.y()) + 53
+            y = int(brect.y()+ offset.y()) + 53 #  53
             x = int(brect.x() + 6)
             w = brect.width()
             h = brect.height()
 
-            qp.drawRect(x,y+3,7,7)
+            if(y >= 50 and y <= 920):
+                qp.drawRect(x+38,y+4,7,7)
 
+        pen = QtGui.QPen(QtGui.QColor("#a69819") ,1, Qt.SolidLine)
+        qp.setPen(pen)
+        brush = QtGui.QBrush(QtGui.QColor("#a69819"))
+        qp.setBrush(brush)
+
+        for block_number in self.highlighter_tans:
+            offset = self.textEdit.contentOffset()
+
+            block= self.textEdit.document().findBlockByNumber(block_number)
+            brect = self.textEdit.blockBoundingGeometry(block)
+            # print("brect", brect)
+            y = int(brect.y()+ offset.y()) + 53 #  53
+            x = int(brect.x() + 6)
+            w = brect.width()
+            h = brect.height()
+
+            if(y >= 50 and y <= 920):
+                qp.drawRect(x+53,y+4,7,7)
+
+        pen = QtGui.QPen(QtGui.QColor("#4bd16f") ,1, Qt.SolidLine)
+        qp.setPen(pen)
+        brush = QtGui.QBrush(QtGui.QColor("#4bd16f"))
+        qp.setBrush(brush)
+
+        for block_number in self.highlighter_bal:
+            offset = self.textEdit.contentOffset()
+
+            block= self.textEdit.document().findBlockByNumber(block_number)
+            brect = self.textEdit.blockBoundingGeometry(block)
+            # print("brect", brect)
+            y = int(brect.y()+ offset.y()) + 53 #  53
+            x = int(brect.x() + 6)
+            w = brect.width()
+            h = brect.height()
+
+            if(y >= 50 and y <= 920):
+                qp.drawRect(x+53,y+4,7,7)
+
+
+        pen = QtGui.QPen(Qt.gray ,1, Qt.SolidLine)
+        qp.setPen(pen)
+        brush = QtGui.QBrush(Qt.gray)
+        qp.setBrush(brush)
+
+
+        for block_number in range(self.textEdit.document().lineCount()):
+
+            offset = self.textEdit.contentOffset()
+
+            block= self.textEdit.document().findBlockByNumber(block_number)
+            brect = self.textEdit.blockBoundingGeometry(block)
+            # print("brect", brect)
+            y = int(brect.y()+ offset.y()) + 53 #  53
+            x = int(brect.x() + 6)
+            w = brect.width()
+            h = brect.height()
+
+            if(y >= 50 and y <= 920):
+                try:
+                    qp.drawText(x,y+9,"%04i" % self.linedict[int(block_number)])
+                except:
+                    self.update_interpreter()
+                    try:
+                        qp.drawText(x,y+9,"--")
+                    except:
+                        pass
 
     def eventFilter(self, obj, event):
         if event.type() == QtCore.QEvent.KeyPress and obj is self.textEdit:
@@ -195,8 +274,6 @@ class CodeEditor(QtWidgets.QDialog):
         start = cursor.selectionStart()
         end = cursor.selectionEnd()
 
-
-
         text = self.textEdit.toPlainText()
 
         mystr = text[:start]
@@ -213,7 +290,6 @@ class CodeEditor(QtWidgets.QDialog):
 
         self.textEdit.setPlainText(mystr)
 
-
         cursor = self.textEdit.textCursor()
         if new_end - start > 1:
 
@@ -225,10 +301,6 @@ class CodeEditor(QtWidgets.QDialog):
         self.textEdit.setTextCursor(cursor)
         self.textEdit.verticalScrollBar().setValue(scroll_pos)
 
-
-
-
-
     def unindent(self):
         # inert tab for whole selection
 
@@ -315,9 +387,18 @@ class CodeEditor(QtWidgets.QDialog):
         code_lines = self.textEdit.toPlainText().split("\n")
 
         self.highlighter_rects = []
+        self.highlighter_tans = []
+        self.highlighter_bal = []
+
         for i,line in enumerate(code_lines):
-            if line.startswith("+[FUN]"):
+            if line.startswith("+[FUN]") or line.startswith("+[INIT]") or line.startswith("+[PARAM]") or line.startswith("+[KNOWS]"):
                 self.highlighter_rects.append(i)
+            elif "<~~>" in line:
+                self.highlighter_tans.append(i)
+
+            elif "ASSETS" in line or "LIABILITIES" in line or "EQUITY" in line:
+                self.highlighter_bal.append(i)
+
         # print("highlighter_rects", self.highlighter_rects)
 
     def update_line_label(self):
@@ -338,7 +419,6 @@ class CodeEditor(QtWidgets.QDialog):
         #self.lineLabel.setText('Row {0:d}, Col {1:d} Python {2:d}'.format(x,y,z))
         self.lineLabel.setText('Line {0:d}, Python: {1:d}'.format(x,z))
 
-
     def update_search(self):
         self.setUpEditor()
         self.update_interpreter()
@@ -346,12 +426,13 @@ class CodeEditor(QtWidgets.QDialog):
     def send_data(self):
         self.box.parent_widget.code_data[self.box.name] = str(self.textEdit.toPlainText())
         # self.close()
-        if self.backup_count == 50:
+        if self.backup_count == 1000:
             self.parent().parent().auto_backup()
             self.backup_count = 0
         self.backup_count += 1
 
     def setUpEditor(self):
+
         self.highlighter = Highlighter(self)
 
         # Agent
